danish
======

Geometric donut engine

Based on

Janish, R.,  "An algorithm for rapid measurement of aberrations in pairs of out-of-focus images", 2012, MIT undergraduate thesis.  https://dspace.mit.edu/handle/1721.1/78543
